/* GENOME BIOINFORMATICS */
/*  RESEARCH LABORATORY  */
/*  Global Style Sheet   */

/*$Id: Genome.css,v 1.28 2003/06/03 16:35:45 gmaster Exp gmaster $*/

BODY, BLOCKQUOTE, P, CENTER,
DD, DIV, FIELDSET, PRE, FORM,
FRAME, FRAMESET, IFRAME, NOFRAMES,
OBJECT, APPLET, HR,
UL, OL, MENU {
           display: block }
LI, DL, DD, DT {
           display: block }
H1, H2, H3, H4, H5, H6 {
           display: table-cell }
HEAD     { display: none }
TABLE    { display: table }
TR       { display: table-row }
TBODY    { display: table-row-group }
COL      { display: table-column }
COLGROUP { display: table-column-group }
TD, TH   { display: table-cell }
IMG      { display: run-in }
TT, CODE, EM {
           display: inline }

BODY {
 background-color: #009F9F;
 color: black;
 border-collapse: collapse;
/* This does not work on newer browsers like N6 */
/*  position: fixed;                            */
 top: 0px;
 bottom: auto;
 left: 0px;
 right: 0px;
 padding: 0px;
 border: 0px;
 line-height/* */ : 1.33em;
}

*, .default {
 top: 0;
 bottom: 0;
 left: 0;
 right: 0;
 border: 0;
 padding: 0;
/* spacing: 0; */
 margin: 0;
 text-indent: 0;
}

.hh {
 line-height/* */ : 80%;
}
.hhh {
 line-height/* */ : 50%;
}

P {
 margin-left: 10px;
 margin-right: 10px;
 margin-bottom: 10px;
 text-align: justify;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: normal;
 font-size: 12px;
}

TEXTAREA {
 font-family: "Monospaced", "Courier", sans-serif;
 font-weight: normal;
 font-size: 12px;
}

INPUT, SELECT {
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: normal;
 font-size: 12px;
}

.tbl {
 vertical-align: top;
 font-family: "Arial", "Helvetica", sans-serif;
/* font-weight: normal; */
 font-size: 12px;
}

A:link {
 color: #008080;
 text-decoration: none;
}
A:visited {
 color: #800000;
 text-decoration: none;
}
A:hover, A:active, A:focus { text-decoration: underline; }
/* :focus { outline: thin solid invert; } */

B {
 font-weight: bold;
}

I {
 font-style: italic;
}

EM {
 font-family: "Monospaced", "Courier", sans-serif;
 font-weight: normal;
 font-style: italic;
 font-stretch: expanded; 
 color: green;
}

TT, CODE {
 font-family: "Monospaced", "Courier", sans-serif;
 font-weight: normal;
}

TT {
 color: gray;
 font-stretch: expanded; 
}

.K, .T { 
 display: run-in
}
H1, H2, .K, .T {
 color: white;
}
H1, H2, .K, .T {
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-stretch: expanded;
 border: none;
 line-height/* */ : 100%;
}
P H1, P H2, P H3, P .K, P .T {
 color: black;
}
H1, .T {
 font-size: 24px;
 padding: 5px;
 text-indent: 0;
 }
H2, .K {
 border: none;
 padding: 0;
 text-indent: 0;
 font-size: 20px;
 width: auto;
 }
H3 { font-size: 16px; }
H4, UL, OL {
 background-color: white;
 color: black;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 12px;
 line-height/* */ : 110%;
}

MENU {
 background-color: white;
 color: black;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: normal;
 font-size: 12px;
 line-height/* */ : 110%;
 list-style: outside;
 list-style-type: circle;
}

UL {
 list-style: outside;
 list-style-type: disc;
}
OL {
 list-style: outside;
 list-style-type: decimal;
}

UL, OL, DL, MENU {
 margin-left: 5px;
 margin-right: 10px; 
}

UL UL, OL OL, MENU * {
 margin-left: 10px;
 margin-right: 10px; 
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: normal;
 font-size: 12px;
}

UL UL UL, OL OL OL {
 margin-left: 15px;
 margin-right: 10px; 
}

LI {
 background-color: white;
 color: black;
}

.lst {
 font-weight: normal; 
}

IMG.pnt {
 padding-left: 5px;
 padding-right: 0px;
}
IMG.mid {
 padding-left: 5px;
}

.ppath {
 color: white;
 background-color: red;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 12px;
 font-weight: bold;
}
.path {
 border: 1px solid #005050;
 color: white;
 background-color: red;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 12px;
 font-weight: bold;
 line-height/* */ : 110%;
}
.path :link, .path :visited {
 color: white;
 text-decoration: none;
}
.path :visited {
 font-weight: bold;
}

.userspace {
 background-color: white;
 color: black;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 12px;
 text-align: justify;
 vertical-align: top;
}

.section {
 background-color: #008080;
 color: white;
 margin-top: 0;
 margin-bottom: 0;
 margin-left: 5px;
 padding-top: 0;
 padding-bottom: 0;
}

#traila {
 text-align: center;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 15px;
 text-align: left;
}
#trailb {
 text-align: center;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 12px;
 color: white;
 line-height/* */ : 85%;
}
#trailc {
 text-align: center;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 15px;
 text-align: right;
}
.trailer {
 padding: 2px;
}

.names {
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 12px;
 color: black;
}

.links {
 vertical-align: top;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 12px;
 line-height/* */ : 95%;
 border: none;
 padding: 0px;
}
.links :link, #traila :link, #trailc :link,
.links :visited, #traila :visited, #trailc :visited {
 color: #005050;
}
.links :hover, .links :active, .links :focus,
.path :hover,   .path :active,  .path :focus {
 text-decoration: underline;
}

.menu {
 text-align: left;
 vertical-align: top; 
}

.title {
 text-align: center;
 vertical-align: middle; 
}

.index {
 color: white;
 line-height/* */ : 100%;
 text-align: center;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-size: 12px;
 border: none;
 padding: 0px;
}

.mvleft {
 position: relative;
 left: -15px;
}

.home {
 line-height/* */ : 80%;
 color: white;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 22px;
 font-weight: bold;
 font-stretch: expanded;
 text-align: center;
 border: none;
}
.tit, .tgen {
 color: white;
 font-family: "Arial", "Helvetica", sans-serif;
 font-weight: bold;
 font-stretch: expanded;
 border: none;
}
.tit {
 font-size: 20px;
 line-height/* */ : 120%;
}
.tgen {
 font-size: 25px;
 line-height/* */ : 100%;
}

.alt {
 display: none;
}

 .float-right {/* paragraph element float */
  float: right;
  width: 30em;
  padding: 0.3em 0.3em 0.3em 0.3em;
  border: 2px dotted #800000;

 }
