/*      GENOME INFORMATICS      */
/*     RESEARCH  LABORATORY     */
/*  GFFTOOLS HowTo Style Sheet  */

/*$Id: HowTo.css,v 1.2 2003/05/30 17:50:58 gmaster Exp $*/
 
H3 {
 display: block;
 line-height: 75%;
 padding-bottom: 0px;
 border-bottom: 0px;
 margin-bottom: 0px;
 margin-top: 8px;
}
.home {
 line-height: 80%;
 color: white;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 18px;
 font-weight: bold;
 font-stretch: expanded;
 text-align: center;
 border: none;
}
.ytbl, .rtbl {
 vertical-align: top;
 font-family: "Arial", "Helvetica", sans-serif;
 font-size: 12px;
}
.ytbl {
 background: #FAFAD2; /* light yellow */
}
.rtbl {
 background: #FFCCAA; /* light red */
}
.codebg { 
 display: table-cell;
 background: #DDFFDD;
}
.codefg {
 font-family: "Monospaced", "Courier", sans-serif;
 font-weight: normal;
 font-size: 12px;
 color: #000000;
}

/*
     FILE ARCHIVED ON 18:54:24 Apr 04, 2005 AND RETRIEVED FROM THE
     INTERNET ARCHIVE ON 09:49:07 Oct 20, 2018.
     JAVASCRIPT APPENDED BY WAYBACK MACHINE, COPYRIGHT INTERNET ARCHIVE.

     ALL OTHER CONTENT MAY ALSO BE PROTECTED BY COPYRIGHT (17 U.S.C.
     SECTION 108(a)(3)).
*/
/*
playback timings (ms):
  LoadShardBlock: 197.985 (3)
  esindex: 0.009
  captures_list: 216.277
  CDXLines.iter: 12.375 (3)
  PetaboxLoader3.datanode: 191.824 (4)
  exclusion.robots: 0.193
  exclusion.robots.policy: 0.18
  RedisCDXSource: 2.583
  PetaboxLoader3.resolve: 79.838 (2)
  load_resource: 101.02
*/