/*     GENOME BIOINFORMATICS   */
/*      RESEARCH LABORATORY    */
/* Forms "Special" Style Sheet */
/* (to apply to mozilla engine */ 
/*  based browsers ---N6, M6,  */
/*  O5, ...--- and IE>5 )      */

/*$Id: Genome_forms_mozilla.css,v 1.9 2003/06/03 16:35:51 gmaster Exp $*/

/* TEXTAREA {        */
/*  display: block;  */
/* }                 */
/* INPUT {           */
/*  display: inline; */
/* }                 */
/* SELECT {          */
/*  display: run-in; */
/* }                 */

HR {
 border: 1px inset;
 color: black;
}

LI, DL, DD, DT {
 display: list-item;
}

P {
 margin-left: 5px;
 margin-right: 5px;
 padding-left: 10px;
}

TEXTAREA {
 cursor: text;
}

TEXTAREA, INPUT, SELECT {
 border-width: thin;
 border-style: solid;
 border-color: black;
 vertical-align: baseline;
}

/* Redefining Sections to improve their boxes  */
.section {
 background-color: #008080;
 color: white;
 margin-top: 0;
 margin-bottom: 0;
 margin-left: 5px;
 padding-top: 3px;
 padding-bottom: 3px;
 padding-left: 5px;
}

UL, OL, DL, MENU {
 margin-left: 30px;
}
UL UL, OL OL, DL DL, MENU * {
 margin-left: 35px;
}
UL UL UL, OL OL OL {
 margin-left: 40px;
}
OL {
 counter-reset: gencnt;    
}
LI:before {
 display: marker;
 marker-offset: 1px;
 text-align: right;
}
OL LI:before {                    
 content: "" counter(gencnt) ".";
 counter-increment: gencnt;    
}
.home {
 line-height/* */ : 150%;
 text-align: center;
}
.tit {
 line-height/* */ : 150%;
}
.tgen {
 line-height/* */ : 120%;
}

P * CENTER {
 text-align: center;
}
